@@ -70,6 +70,11 @@ public:
         QStandardItem::setData(value, role);
     }
 
+    FlatpakRemote *remote() const
+    {
+        return m_remote;
+    }
+
 private:
     FlatpakInstallation *m_installation = nullptr;
     FlatpakRemote *const m_remote;
@@ -81,8 +86,13 @@ FlatpakSourcesBackend::FlatpakSourcesBackend(const QVector<FlatpakInstallation *
     , m_preferredInstallation(installations.constFirst())
     , m_sources(new QStandardItemModel(this))
     , m_flathubAction(new DiscoverAction("flatpak-discover", i18n("Add Flathub"), this))
+    , m_saveAction(new DiscoverAction("dialog-ok-apply", i18n("Apply Changes"), this))
     , m_noSourcesItem(new QStandardItem(QStringLiteral("-")))
 {
+    m_saveAction->setVisible(false);
+    m_saveAction->setToolTip(i18n("Changes to the priority of Flatpak sources must be applied before they will take effect."));
+    connect(m_saveAction, &DiscoverAction::triggered, this, &FlatpakSourcesBackend::save);
+
     m_flathubAction->setObjectName(QStringLiteral("flathub"));
     m_flathubAction->setToolTip(i18n("Makes it possible to easily install the applications listed in https://flathub.org"));
     connect(m_flathubAction, &DiscoverAction::triggered, this, [this]() {
@@ -111,6 +121,28 @@ FlatpakSourcesBackend::~FlatpakSourcesBackend()
         delete m_noSourcesItem;
 }
 
+void FlatpakSourcesBackend::save()
+{
+    int last = INT_MIN;
+    for (int i = m_sources->rowCount() - 1; i >= 0; --i) {
+        auto it = m_sources->item(i);
+        const int prio = it->data(PrioRole).toInt();
+        if (prio <= last) {
+            FlatpakSourceItem *sourceItem = static_cast<FlatpakSourceItem *>(it);
+            flatpak_remote_set_prio(sourceItem->remote(), ++last);
+            g_autoptr(GError) error = nullptr;
+            if (!flatpak_installation_modify_remote(sourceItem->flatpakInstallation(), sourceItem->remote(), nullptr, &error)) {
+                qDebug() << "failed setting priorities" << error->message;
+            }
+
+            it->setData(last, PrioRole);
+        } else {
+            last = prio;
+        }
+    }
+    m_saveAction->setVisible(false);
+}
+
 QAbstractItemModel *FlatpakSourcesBackend::sources()
 {
     return m_sources;
@@ -302,6 +334,11 @@ void FlatpakSourcesBackend::addRemote(FlatpakRemote *remote, FlatpakInstallation
     }
 
     for (int i = 0, c = m_sources->rowCount(); i < c; ++i) {
+        auto genItem = m_sources->item(i);
+        if (genItem == m_noSourcesItem) {
+            continue;
+        }
+
         FlatpakSourceItem *item = static_cast<FlatpakSourceItem *>(m_sources->item(i));
         if (item->data(Qt::StatusTipRole) == remoteUrl && item->flatpakInstallation() == installation) {
             qDebug() << "we already have an item for this" << remoteUrl;
@@ -366,12 +403,13 @@ bool FlatpakSourcesBackend::moveSource(const QString &sourceId, int delta)
     auto prevRow = m_sources->takeRow(row);
     Q_ASSERT(!prevRow.isEmpty());
 
-    const auto destRow = row + (delta > 0 ? delta : delta);
+    const auto destRow = row + delta;
     m_sources->insertRow(destRow, prevRow);
     if (destRow == 0 || row == 0)
         Q_EMIT firstSourceIdChanged();
     if (destRow == m_sources->rowCount() - 1 || row == m_sources->rowCount() - 1)
         Q_EMIT lastSourceIdChanged();
+    m_saveAction->setVisible(true);
     return true;
 }
 
