@@ -119,10 +119,22 @@ void FwupdBackend::addUpdates()
                     FwupdRelease *release = (FwupdRelease *)g_ptr_array_index(rels, j);
                     if (!fwupd_release_get_description(release))
                         continue;
-                    longdescription += QStringLiteral("Version %1\n").arg(QString::fromUtf8(fwupd_release_get_version(release)));
-                    longdescription += QString::fromUtf8(fwupd_release_get_description(release)) + QLatin1Char('\n');
+                    if (rels->len > 1) {
+                        longdescription += QStringLiteral("Version %1\n").arg(QString::fromUtf8(fwupd_release_get_version(release)));
+                    }
+                    longdescription += QString::fromUtf8(fwupd_release_get_description(release));
+                    if (rels->len > 1) {
+                        longdescription += QLatin1Char('\n');
+                    }
                 }
                 res->setDescription(longdescription);
+
+                // Make sure to set the installed version of the current thing so
+                // they can both be shown in the update page UI
+                auto installedResource = m_resources[res->packageName()];
+                if (installedResource) {
+                    res->setInstalledVersion(installedResource->availableVersion());
+                }
                 addResource(res);
             }
         } else {
@@ -352,7 +364,7 @@ ResultsStream *FwupdBackend::search(const AbstractResourcesBackend::Filters &fil
     auto stream = new ResultsStream(QStringLiteral("FwupdStream"));
     auto f = [this, stream, filter]() {
         QVector<AbstractResource *> ret;
-        foreach (AbstractResource *r, m_resources) {
+        for (AbstractResource *r : qAsConst(m_resources)) {
             if (r->state() < filter.state)
                 continue;
 
