@@ -8,6 +8,7 @@
 #define ABSTRACTRESOURCE_H
 
 #include <QCollatorSortKey>
+#include <QColor>
 #include <QDate>
 #include <QJsonArray>
 #include <QJsonObject>
@@ -47,9 +48,10 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
     Q_PROPERTY(QUrl helpURL READ helpURL CONSTANT)
     Q_PROPERTY(QUrl bugURL READ bugURL CONSTANT)
     Q_PROPERTY(QUrl donationURL READ donationURL CONSTANT)
+    Q_PROPERTY(QUrl contributeURL READ contributeURL CONSTANT)
     Q_PROPERTY(bool canUpgrade READ canUpgrade NOTIFY stateChanged)
     Q_PROPERTY(bool isInstalled READ isInstalled NOTIFY stateChanged)
-    Q_PROPERTY(QJsonArray licenses READ licenses CONSTANT)
+    Q_PROPERTY(QJsonArray licenses READ licenses NOTIFY licensesChanged)
     Q_PROPERTY(QString longDescription READ longDescription NOTIFY longDescriptionChanged)
     Q_PROPERTY(QString origin READ origin CONSTANT)
     Q_PROPERTY(QString displayOrigin READ displayOrigin CONSTANT)
@@ -59,7 +61,7 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
     Q_PROPERTY(QString availableVersion READ availableVersion NOTIFY versionsChanged)
     Q_PROPERTY(QString section READ section CONSTANT)
     Q_PROPERTY(QStringList mimetypes READ mimetypes CONSTANT)
-    Q_PROPERTY(AbstractResourcesBackend *backend READ backend CONSTANT)
+    Q_PROPERTY(QObject *backend READ backendObject CONSTANT)
     Q_PROPERTY(QVariant rating READ ratingVariant NOTIFY ratingFetched)
     Q_PROPERTY(QString appstreamId READ appstreamId CONSTANT)
     Q_PROPERTY(QString categoryDisplay READ categoryDisplay CONSTANT)
@@ -71,6 +73,10 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
     Q_PROPERTY(QString upgradeText READ upgradeText NOTIFY versionsChanged)
     Q_PROPERTY(bool isRemovable READ isRemovable CONSTANT)
     Q_PROPERTY(QString versionString READ versionString NOTIFY versionsChanged)
+    Q_PROPERTY(QString contentRatingText READ contentRatingText CONSTANT)
+    Q_PROPERTY(QString contentRatingDescription READ contentRatingDescription CONSTANT)
+    Q_PROPERTY(ContentIntensity contentRatingIntensity READ contentRatingIntensity CONSTANT)
+    Q_PROPERTY(uint contentRatingMinimumAge READ contentRatingMinimumAge CONSTANT)
 public:
     /**
      * This describes the state of the resource
@@ -95,6 +101,12 @@ public:
     };
     Q_ENUM(State)
 
+    enum ContentIntensity {
+        Mild,
+        Intense,
+    };
+    Q_ENUM(ContentIntensity)
+
     /**
      * Constructs the AbstractResource with its corresponding backend
      */
@@ -131,13 +143,15 @@ public:
     virtual QUrl bugURL();
     ///@returns a URL that points to the place where you can donate money to the app developer
     virtual QUrl donationURL();
+    ///@returns a URL that points to the place where you can contribute to develop the app
+    virtual QUrl contributeURL();
 
     enum Type {
         Application,
         Addon,
         Technical,
     };
-    Q_ENUM(Type);
+    Q_ENUM(Type)
     virtual Type type() const = 0;
 
     virtual quint64 size() = 0;
@@ -175,6 +189,7 @@ public:
     virtual QString status();
 
     AbstractResourcesBackend *backend() const;
+    QObject *backendObject() const;
 
     /**
      * @returns a name sort key for faster sorting
@@ -227,6 +242,11 @@ public:
 
     virtual QString versionString();
 
+    virtual QString contentRatingText() const;
+    virtual ContentIntensity contentRatingIntensity() const;
+    virtual QString contentRatingDescription() const;
+    virtual uint contentRatingMinimumAge() const;
+
 public Q_SLOTS:
     virtual void fetchScreenshots();
     virtual void fetchChangelog() = 0;
@@ -239,6 +259,7 @@ Q_SIGNALS:
     void iconChanged();
     void sizeChanged();
     void stateChanged();
+    void licensesChanged();
     void ratingFetched();
     void longDescriptionChanged();
     void versionsChanged();
