@@ -106,7 +106,7 @@ public:
     }
     QString name() const override
     {
-        return i18n("Updates");
+        return i18n("Updating");
     }
 
 Q_SIGNALS:
@@ -141,6 +141,7 @@ void ResourcesUpdatesModel::init()
             connect(updater, &AbstractBackendUpdater::passiveMessage, this, &ResourcesUpdatesModel::passiveMessage);
             connect(updater, &AbstractBackendUpdater::needsRebootChanged, this, &ResourcesUpdatesModel::needsRebootChanged);
             connect(updater, &AbstractBackendUpdater::destroyed, this, &ResourcesUpdatesModel::updaterDestroyed);
+            connect(updater, &AbstractBackendUpdater::errorMessageChanged, this, &ResourcesUpdatesModel::errorMessagesChanged);
             m_updaters += updater;
 
             m_lastIsProgressing |= updater->isProgressing();
@@ -154,7 +155,7 @@ void ResourcesUpdatesModel::init()
     m_offlineUpdates = group.readEntry<bool>("UseOfflineUpdates", false);
 
     KConfigWatcher::Ptr watcher = KConfigWatcher::create(sharedConfig);
-    connect(watcher.data(), &KConfigWatcher::configChanged, [this](const KConfigGroup &group, const QByteArrayList &names) {
+    connect(watcher.data(), &KConfigWatcher::configChanged, this, [this](const KConfigGroup &group, const QByteArrayList &names) {
         // Ensure it is for the right file
         if (!names.contains("UseOfflineUpdates") || group.name() != "Software") {
             return;
@@ -174,11 +175,18 @@ void ResourcesUpdatesModel::init()
             setTransaction(updateTransaction);
         }
     }
+
+    Q_EMIT errorMessagesChanged();
 }
 
 void ResourcesUpdatesModel::updaterDestroyed(QObject *obj)
 {
-    m_updaters.removeAll(static_cast<AbstractBackendUpdater *>(obj));
+    for (auto it = m_updaters.begin(); it != m_updaters.end();) {
+        if (*it == obj)
+            it = m_updaters.erase(it);
+        else
+            ++it;
+    }
 }
 
 void ResourcesUpdatesModel::message(const QString &msg)
@@ -336,4 +344,17 @@ void ResourcesUpdatesModel::setOfflineUpdates(bool offline)
     m_offlineUpdates = offline;
 }
 
+QStringList ResourcesUpdatesModel::errorMessages() const
+{
+    QStringList ret;
+    for (auto updater : m_updaters) {
+        const auto error = updater->errorMessage();
+        if (!error.isEmpty()) {
+            ret << error;
+        }
+    }
+    ret.removeDuplicates();
+    return ret;
+}
+
 #include "ResourcesUpdatesModel.moc"
